@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 13415 2022-04-13 06:21:20Z Jason $
+# $Id: __init__.py 13525 2022-06-08 01:07:27Z Jacky $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Jason $ (last)
-# $Date: 2022-04-13 14:21:20 +0800 (Wed, 13 Apr 2022) $
-# $Revision: 13415 $
+# $Author: Jacky $ (last)
+# $Date: 2022-06-08 09:07:27 +0800 (週三, 08 六月 2022) $
+# $Revision: 13525 $
 
 from __future__ import print_function
 
@@ -655,7 +655,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
         'BACKEND': 'django.template.backends.django.DjangoTemplates',
         'DIRS': [os.path.join(settingsDict.get('BASE_DIR', projectPath),
                               'templates'),],
-        # ݭnoӤ~ site-packages ̭ templates
+        # need this to find the templates in site-packages
         'APP_DIRS': True,
         'OPTIONS': {
             'context_processors': [
@@ -706,17 +706,17 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
 
     update(settingsDict, authPasswordValidators)
     #=========================================================================
-    
+
     #=========================================================================
     #  Security
     #  Ref: https://chipcullen.com/django-3-referrer-policy-change/
     secureFeferrerPolicy = {
         'SECURE_REFERRER_POLICY': 'no-referrer-when-downgrade'
     }
-    
+
     update(settingsDict, secureFeferrerPolicy)
     #=========================================================================
-    
+
     #=========================================================================
     # Django plugins.
     middleware = [
@@ -776,6 +776,14 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
     extendMiddlewareClasses(settingsDict, ADDING_MIDDLEWARE)
     #=========================================================================
 
+    #=========================================================================
+    # Django hijack.
+    if settingsDict.get('IUNO_HIJACK_ENABLE'):
+        extendInstalledApps(settingsDict, ['hijack', 'hijack.contrib.admin', ])
+        extendMiddlewareClasses(settingsDict, ['hijack.middleware.HijackUserMiddleware', ])
+
+    #=========================================================================
+
     #=========================================================================
     # Iuno.cloud.
     try:
@@ -1095,7 +1103,7 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
 
         if getattr(settings, 'IUNO_SHOP_ENABLE', None) and module:
             Iuno.shop.attachURLs(settings, urlpatterns)
-        
+
     #==========================================================================
     # Iuno.test.
     if not "Iuno.test" in excludeApps:
@@ -1109,6 +1117,14 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
                 url(r"^remote/test/$", test, name="remoteTest"),
             )
 
+    #==========================================================================
+    # Django hijack.
+    if getattr(settings, 'IUNO_HIJACK_ENABLE', None):
+        urlpatterns += patterns('',
+            url(r'^_hijack/', include('hijack.urls')),
+        )
+    #==========================================================================
+
     #==========================================================================
     # DEBUG mode media
     if settings.DEBUG == False and settings.SERVER_MODE == settings.DEVELOPMENT:
@@ -1125,7 +1141,7 @@ def attachURLs(settings, urlpatterns, excludeApps=()):
                     'document_root': settings.MEDIA_ROOT,
                 })
             )
-            
+
     #==========================================================================
     # DEBUG toolbar
     if getattr(settings, 'DEBUG_TOOLBAR_ENABLE', None):
